==> ui-0.2.43.tgz: package/lib/cjs/HelperText/HelperText.styled.js <==
"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.DSHelperTextWrapper = void 0;
var _base = _interopRequireDefault(require("@emotion/styled/base"));
var _foundations = require("../@foundations");
const DSHelperTextWrapper = /*#__PURE__*/(0, _base.default)("span", process.env.NODE_ENV === "production" ? {
  target: "efte5n90"
} : {
  target: "efte5n90",
  label: "DSHelperTextWrapper"
})("margin-top:4px;margin-left:16px;font-size:12px;font-weight:400;line-height:18px;color:", _ref => {
  let {
    $color
  } = _ref;
  return _foundations.Theme.HelperTextColor[$color];
}, ";" + (process.env.NODE_ENV === "production" ? "" : "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkhlbHBlclRleHQvSGVscGVyVGV4dC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBRStDIiwiZmlsZSI6IkhlbHBlclRleHQvSGVscGVyVGV4dC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBUaGVtZSB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNIZWxwZXJUZXh0V3JhcHBlciA9IHN0eWxlZC5zcGFuIGBcbiAgbWFyZ2luLXRvcDogNHB4O1xuICBtYXJnaW4tbGVmdDogMTZweDtcbiAgZm9udC1zaXplOiAxMnB4O1xuICBmb250LXdlaWdodDogNDAwO1xuICBsaW5lLWhlaWdodDogMThweDtcbiAgY29sb3I6ICR7KHsgJGNvbG9yIH0pID0+IFRoZW1lLkhlbHBlclRleHRDb2xvclskY29sb3JdfTtcbmA7XG4iXX0= */"));
exports.DSHelperTextWrapper = DSHelperTextWrapper;

==> ui-0.2.52.tgz: package/lib/cjs/HelperText/HelperText.styled.js <==
"use strict";

var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.DSHelperTextWrapper = void 0;
var _base = _interopRequireDefault(require("@emotion/styled/base"));
var _foundations = require("../@foundations");
const DSHelperTextWrapper = exports.DSHelperTextWrapper = /*#__PURE__*/(0, _base.default)("span", process.env.NODE_ENV === "production" ? {
  target: "efte5n90"
} : {
  target: "efte5n90",
  label: "DSHelperTextWrapper"
})("margin-top:4px;margin-left:16px;font-size:12px;font-weight:400;line-height:18px;color:", _ref => {
  let {
    $color
  } = _ref;
  return _foundations.Theme.HelperTextColor[$color];
}, ";" + (process.env.NODE_ENV === "production" ? "" : "/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbIkhlbHBlclRleHQvSGVscGVyVGV4dC5zdHlsZWQuanMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBRStDIiwiZmlsZSI6IkhlbHBlclRleHQvSGVscGVyVGV4dC5zdHlsZWQuanMiLCJzb3VyY2VzQ29udGVudCI6WyJpbXBvcnQgc3R5bGVkIGZyb20gJ0BlbW90aW9uL3N0eWxlZCc7XG5pbXBvcnQgeyBUaGVtZSB9IGZyb20gJy4uL0Bmb3VuZGF0aW9ucyc7XG5leHBvcnQgY29uc3QgRFNIZWxwZXJUZXh0V3JhcHBlciA9IHN0eWxlZC5zcGFuIGBcbiAgbWFyZ2luLXRvcDogNHB4O1xuICBtYXJnaW4tbGVmdDogMTZweDtcbiAgZm9udC1zaXplOiAxMnB4O1xuICBmb250LXdlaWdodDogNDAwO1xuICBsaW5lLWhlaWdodDogMThweDtcbiAgY29sb3I6ICR7KHsgJGNvbG9yIH0pID0+IFRoZW1lLkhlbHBlclRleHRDb2xvclskY29sb3JdfTtcbmA7XG4iXX0= */"));
